pub struct Trust {
pub keys: Vec<String>,
}Expand description
Trust roots: paths (manifest-relative) to trusted signer public keys, PEM (ADR 000006).
PartialEq lets reload detect a trust-section change (which it rejects — trust is fixed
at construction, f000004 #1).
Fields
keys: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Trust
impl<'de> Deserialize<'de> for Trust
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Trust
Sourceimpl JsonSchema for Trust
impl JsonSchema for Trust
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Trust